Object.defineProperty(exports, "__esModule", { value: true });
exports.NodeClient = void 0;
var tslib_1 = require("tslib");
var types_1 = require("@amplitude/types");
var utils_1 = require("@amplitude/utils");
var retryHandler_1 = require("./retryHandler");
var constants_1 = require("./constants");
var NodeClient = /** @class */ (function () {
    /**
     * Initializes this client instance.
     *
     * @param apiKey API key for your project
     * @param options options for the client
     */
    function NodeClient(apiKey, options) {
        if (options === void 0) { options = {}; }
        this._events = [];
        this._flushTimer = null;
        this._apiKey = apiKey;
        this._options = Object.assign({}, constants_1.DEFAULT_OPTIONS, options);
        this._transportWithRetry = this._options.retryClass || this._setupDefaultTransport();
        this._setUpLogging();
    }
    /**
     * @inheritDoc
     */
    NodeClient.prototype.getOptions = function () {
        return this._options;
    };
    /**
     * @inheritDoc
     */
    NodeClient.prototype.flush = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var arrayLength, eventsToSend;
            return tslib_1.__generator(this, function (_a) {
                // Clear the timeout
                if (this._flushTimer !== null) {
                    clearTimeout(this._flushTimer);
                }
                arrayLength = this._events.length;
                if (arrayLength === 0) {
                    return [2 /*return*/, { status: types_1.Status.Success, statusCode: 200 }];
                }
                eventsToSend = this._events.splice(0, arrayLength);
                return [2 /*return*/, this._transportWithRetry.sendEventsWithRetry(eventsToSend)];
            });
        });
    };
    /**
     * @inheritDoc
     */
    NodeClient.prototype.logEvent = function (event) {
        var _this = this;
        if (this._options.optOut === true) {
            return;
        }
        this._annotateEvent(event);
        // Add event to unsent events queue.
        this._events.push(event);
        if (this._events.length >= this._options.maxCachedEvents) {
            // # of events exceeds the limit, flush them.
            this.flush();
        }
        else {
            // Not ready to flush them and not timing yet, then set the timeout
            if (this._flushTimer === null) {
                this._flushTimer = setTimeout(function () {
                    _this.flush();
                }, this._options.uploadIntervalInSec * 1000);
            }
        }
    };
    /** Add platform dependent field onto event. */
    NodeClient.prototype._annotateEvent = function (event) {
        event.library = constants_1.SDK_NAME + "/" + constants_1.SDK_VERSION;
        event.platform = 'Node.js';
    };
    NodeClient.prototype._setupDefaultTransport = function () {
        return new retryHandler_1.RetryHandler(this._apiKey, this._options);
    };
    NodeClient.prototype._setUpLogging = function () {
        if (this._options.debug || this._options.logLevel) {
            if (this._options.logLevel) {
                utils_1.logger.enable(this._options.logLevel);
            }
            else {
                utils_1.logger.enable();
            }
        }
    };
    return NodeClient;
}());
exports.NodeClient = NodeClient;
//# sourceMappingURL=nodeClient.js.map